% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core-fit.R
\name{sparse_quantile}
\alias{sparse_quantile}
\title{Quantile sparsification}
\usage{
sparse_quantile(Isigma_star, quantile_level)
}
\description{
Quantile sparsification
}
\keyword{internal}
